@@ -34,7 +34,8 @@ class Application:
         self.device.con.get(path="launchApp", args="sopid=" + self.sopId + "&" + "uiappid=" + self.uiAppId)
         if timeout is None:
             timeout = self.device.default_timeout
-        for m_iter in range(0, timeout):
+        die_time = int(time.time()) + timeout
+        while int(time.time()) < die_time:
             self.device.refresh_layout()
             selector = etree.XML(self.device.xmlStr.encode('utf-8'))
             if selector.get("sopId") == self.sopId:
@@ -53,9 +54,6 @@ class Application:
     def close(self):
         self.device.con.get(path="quitApp", args="sopid=" + self.sopId)
 
-    def __get_device_default_time(self):
-        return self.device.default_timeout
-
     def find_item_by_xpath_key(self, xpath_key, timeout=None):
         i = self.__find_item_by_xpath(self.device.get_xpath(self.sopId, xpath_key), timeout)
         self.device.log("debug", "find_item_by_xpath_key(), xpath_key=%s, find Item successful, %s" % (xpath_key, str(i)))
@@ -69,9 +67,9 @@ class Application:
     def __find_item_by_xpath(self, xpath, timeout=None):
         if timeout is None:
             timeout = self.device.default_timeout
-        for m_iter in range(0, timeout):
-            if m_iter > 0:
-                sleep(1)
+        sleep(0.5)
+        die_time = int(time.time()) + timeout
+        while int(time.time()) < die_time:
             self.device.refresh_layout()
             selector = etree.XML(self.device.xmlStr.encode('utf-8'))
             nodes = selector.xpath(xpath)
@@ -82,6 +80,7 @@ class Application:
                     return i
             else:
                 raise Exception('error: application is not the top window!')
+            sleep(0.5)
         raise Exception('timeout: not found that item!')
 
     def clear_data(self):
