@@ -13,6 +13,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
+import time
 
 import sympy as sp
 import math
@@ -214,12 +215,13 @@ class Item:
     def exist(self, timeout=None):
         if timeout is None:
             timeout = self.device.default_timeout
-        for m_iter in range(0, timeout):
-            if m_iter > 0:
-                sleep(1)
+        sleep(3)
+        die_time = int(time.time()) + timeout
+        while int(time.time()) < die_time:
             self.rect = self.__exist()
             if len(self.rect) > 0:
                 return True
+            sleep(0.5)
         return False
 
     def __exist(self):
@@ -236,7 +238,7 @@ class Item:
                     image = self.__xml_tree_traversed(surface.childNodes, 1)
                 else:
                     image = self.__img_cover(image, self.__xml_tree_traversed(surface.childNodes, 1))
-            # cv2.imshow("ss", image)
+            # cv2.imshow(str(self.device.system_time()), image)
             # cv2.waitKey(0)
             b, g, r = cv2.split(image)
             if len(np.argwhere(r == 255)) > 0:
@@ -567,20 +569,15 @@ class Item:
         self.device.click(self.__center_x_to_global, self.__center_y_to_global)
 
     def click_exist(self, timeout=None):
-        if timeout is None:
-            timeout = self.device.default_timeout
-        for m_iter in range(0, timeout):
-            if m_iter > 0:
-                sleep(1)
-            if self.exist():
-                if (self.rect[len(self.rect) - 1][1] - self.rect[0][1] + 1) \
-                        * (self.rect[len(self.rect) - 1][0] - self.rect[0][0] + 1) == len(self.rect):
-                    x = self.rect[0][1] + int((self.rect[len(self.rect) - 1][1] - self.rect[0][1] + 1) / 2)
-                    y = self.rect[0][0] + int((self.rect[len(self.rect) - 1][0] - self.rect[0][0] + 1) / 2)
-                    self.device.click(x, y)
-                    return True
-                self.device.click(self.rect[100][1], self.rect[100][0])
+        if self.exist(timeout):
+            if (self.rect[len(self.rect) - 1][1] - self.rect[0][1] + 1) \
+                    * (self.rect[len(self.rect) - 1][0] - self.rect[0][0] + 1) == len(self.rect):
+                x = self.rect[0][1] + int((self.rect[len(self.rect) - 1][1] - self.rect[0][1] + 1) / 2)
+                y = self.rect[0][0] + int((self.rect[len(self.rect) - 1][0] - self.rect[0][0] + 1) / 2)
+                self.device.click(x, y)
                 return True
+            self.device.click(self.rect[100][1], self.rect[100][0])
+            return True
         return False
 
     def submit_string(self, text):
